pub fn aggregate_changes(changes: Vec<SemanticChange>) -> AggregationResultExpand description
Aggregate a flat list of semantic changes into groups where possible.
pub fn aggregate_changes(changes: Vec<SemanticChange>) -> AggregationResultAggregate a flat list of semantic changes into groups where possible.