pub struct FunctionRenameCandidate {
pub new_name: String,
pub confidence: f64,
pub body_changed: bool,
}Expand description
One structurally plausible target for a function that disappeared under its old name.
Fields
new_name: Stringconfidence: f64body_changed: boolWhether bytes other than the consistently renamed function name changed.