Module diff

Module diff 

Semantic diff: detect high-level code changes.

Structs

SemanticBudget
Resource limits used by semantic analysis.
SemanticCheckOnlyResult
Result of the cheap semantic no-op check.
SemanticDiffOptions
Options for semantic diff analysis.
SemanticDiffResult
Result of full semantic diff analysis.
SemanticSummaryResult
Aggregated semantic summary without the full detailed change list.
WorktreeStatus
Worktree status summary.

Enums

DiffKind
Kind of file change.
SemanticCheckStatus
Result classification for the cheap semantic check path.
SemanticFallbackReason
Conservative reason that semantic analysis skipped or degraded work.

Functions

semantic_check_only
Perform a cheap semantic no-op check between two trees.
semantic_check_only_with_cache
Perform a cheap semantic no-op check between two trees using an injected cache.
semantic_check_only_worktree
Perform a cheap semantic no-op check between a tree and worktree content.
semantic_check_only_worktree_with_cache
Perform a cheap semantic no-op check between a tree and worktree content using an injected cache.
semantic_diff
Perform semantic diff analysis between two trees.
semantic_diff_summary
Perform semantic summary analysis between two trees.
semantic_diff_summary_with_cache
Perform semantic summary analysis between two trees using an injected cache.
semantic_diff_summary_worktree
Perform semantic summary between a tree and worktree content.
semantic_diff_summary_worktree_with_cache
Perform semantic summary between a tree and worktree content using an injected cache.
semantic_diff_with_cache
Perform semantic diff analysis between two trees using an injected cache.
semantic_diff_worktree
Perform semantic diff between a tree and worktree content.
semantic_diff_worktree_with_cache
Perform semantic diff between a tree and worktree content using an injected cache.