Semantic diff: detect high-level code changes.
Structs
- Semantic
Budget - Resource limits used by semantic analysis.
- Semantic
Check Only Result - Result of the cheap semantic no-op check.
- Semantic
Diff Options - Options for semantic diff analysis.
- Semantic
Diff Result - Result of full semantic diff analysis.
- Semantic
Summary Result - Aggregated semantic summary without the full detailed change list.
- Worktree
Status - Worktree status summary.
Enums
- Diff
Kind - Kind of file change.
- Semantic
Check Status - Result classification for the cheap semantic check path.
- Semantic
Fallback Reason - Conservative reason that semantic analysis skipped or degraded work.
Functions
- semantic_
check_ only - Perform a cheap semantic no-op check between two trees.
- semantic_
check_ only_ with_ cache - Perform a cheap semantic no-op check between two trees using an injected cache.
- semantic_
check_ only_ worktree - Perform a cheap semantic no-op check between a tree and worktree content.
- semantic_
check_ only_ worktree_ with_ cache - Perform a cheap semantic no-op check between a tree and worktree content using an injected cache.
- semantic_
diff - Perform semantic diff analysis between two trees.
- semantic_
diff_ summary - Perform semantic summary analysis between two trees.
- semantic_
diff_ summary_ with_ cache - Perform semantic summary analysis between two trees using an injected cache.
- semantic_
diff_ summary_ worktree - Perform semantic summary between a tree and worktree content.
- semantic_
diff_ summary_ worktree_ with_ cache - Perform semantic summary between a tree and worktree content using an injected cache.
- semantic_
diff_ with_ cache - Perform semantic diff analysis between two trees using an injected cache.
- semantic_
diff_ worktree - Perform semantic diff between a tree and worktree content.
- semantic_
diff_ worktree_ with_ cache - Perform semantic diff between a tree and worktree content using an injected cache.