Module parser

Module parser 

Language parsing using tree-sitter.

Structs

FunctionDef
A function definition.
FunctionRef
Borrowed view of a function indexed in a SyntaxIndex.
Import
An import statement.
ImportRef
Borrowed view of an import indexed in a SyntaxIndex.
ParsedFile
A parsed file with its tree-sitter AST and Heddle-owned syntax index.
SyntaxIndex
Compact Heddle-owned syntax data for one parsed source file.

Enums

ImportKind
Type of import.
Language
Supported programming languages.

Functions

extract_dependencies
Extract dependencies from a parsed file.